@@ -329,6 +329,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Vovida Software License 1.0",
     "License :: OSI Approved :: W3C License",
     "License :: OSI Approved :: X.Net License",
+    "License :: OSI Approved :: Zero-Clause BSD (0BSD)",
     "License :: OSI Approved :: Zope Public License",
     "License :: OSI Approved :: zlib/libpng License",
     "License :: Other/Proprietary License",
@@ -730,6 +731,9 @@ sorted_classifiers: List[str] = [
     "Topic :: Software Development :: Disassemblers",
     "Topic :: Software Development :: Documentation",
     "Topic :: Software Development :: Embedded Systems",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN)",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: CANopen",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: J1939",
     "Topic :: Software Development :: Internationalization",
     "Topic :: Software Development :: Interpreters",
     "Topic :: Software Development :: Libraries",
